@@ -1,3 +1,4 @@
+from livestyled.models.app import Currency
 from livestyled.models.event import Event, EventDate
 from livestyled.models.ticket_integration import TicketIntegration
 from livestyled.models.user import User
@@ -50,7 +51,8 @@ class Ticket:
             venue=None,
             event=None,
             ticket_auth=None,
-            event_date=None
+            event_date=None,
+            currency=None
     ):
         self.id = id
         self.external_ticket_id = external_ticket_id
@@ -146,6 +148,14 @@ class Ticket:
         else:
             self.venue = None
 
+        if currency:
+            if isinstance(currency, Currency):
+                self.currency = currency
+            elif isinstance(currency, dict):
+                self.currency = Currency(**currency)
+        else:
+            self.currency = None
+
     @classmethod
     def placeholder(
             cls,
@@ -193,7 +203,8 @@ class Ticket:
             map_image_url=None,
             ticket_integration=None,
             venue=None,
-            event=None
+            event=None,
+            currency=None
         )
 
     @classmethod
@@ -238,6 +249,7 @@ class Ticket:
             ticket_integration=None,
             venue: Venue or str or int or None = None,
             event: Event or str or int or None = None,
+            currency: Currency or None = None
     ):
         ticket = Ticket(
             id=None,
@@ -282,6 +294,7 @@ class Ticket:
             ticket_integration=ticket_integration,
             venue=venue,
             event=event,
+            currency=currency
         )
         if isinstance(user, (str, int)):
             user = User.placeholder(id=user)
@@ -349,7 +362,7 @@ class Ticket:
             'price', 'status', 'can_share', 'sharer_email', 'redeemed_at', 'redeemer_id', 'share_code',
             'redeemer_email', 'parent_ticket', 'shared_at', 'legal_long_text', 'legal_short_text', 'map_url',
             'map_image_url', 'ticket_integration', 'entrance', 'row', 'section', 'price_code', 'external_customer_ref',
-            'venue', 'event', 'event_date'
+            'venue', 'event', 'event_date', 'currency'
         )
         for field in fields:
             if getattr(self, field) != getattr(other, field):
