@@ -11,6 +11,7 @@ from livestyled.models import (
     Booking,
     Cohort,
     Competition,
+    Currency,
     Device,
     DeviceFormData,
     DevicePreference,
@@ -53,6 +54,7 @@ from livestyled.schemas import (
     BookingSchema,
     CohortSchema,
     CompetitionSchema,
+    CurrencySchema,
     DeviceFormDataSchema,
     DevicePreferenceSchema,
     DeviceRealitySchema,
@@ -584,17 +586,22 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
             self,
             external_ticket_ids: dict or None = None,
             user: User or str or int or None = None,
+            filters: dict or None = None
     ) -> Generator[Ticket, None, None]:
-        filters = {}
+        ticket_filters = {}
         if external_ticket_ids:
-            filters['externalTicketId[]'] = external_ticket_ids
+            ticket_filters['externalTicketId[]'] = external_ticket_ids
         if user:
             if isinstance(user, User):
-                filters['user'] = '{}'.format(user.id)
+                ticket_filters['user'] = '{}'.format(user.id)
             else:
-                filters['user'] = '{}'.format(user)
+                ticket_filters['user'] = '{}'.format(user)
+
         if filters:
-            return self._get_resource_list(TicketSchema, filters=filters)
+            ticket_filters.update(filters)
+
+        if ticket_filters:
+            return self._get_resource_list(TicketSchema, filters=ticket_filters)
         else:
             return self._get_resource_list(TicketSchema)
 
@@ -1308,3 +1315,10 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
         if filters:
             return self._get_resource_list(DeviceFormDataSchema, filters=filters)
         return self._get_resource_list(DeviceFormDataSchema)
+
+    # ---- CURRENCIES
+
+    def get_currencies(
+            self,
+    ) -> Generator[Currency, None, None]:
+        return self._get_resource_list(CurrencySchema)
